{% extends 'base.html' %}

{% block title %}
Fake Email Server
{% endblock %}

{% block content %}

    <ul>
        {% for count, name in address_list %}
        <li>({{ count }}) - <a href='{{ name }}'>{{ name }}</a></li>
        {% endfor %}
    </ul>

    <form action='.' method='POST'><input type='submit' value='Clear All'></form>
{% endblock %}