<!DOCTYPE HTML>
<html>
    <head>
        <meta charset="UTF-8">
        <title>{% block title %}{% endblock %}</title>
        <script type="text/javascript" src="http://ajax.googleapis.com/ajax/libs/jquery/1.4.3/jquery.min.js"></script>

        <style type="text/css">
            body {
                font-family: monospace;
            }

            span.part {
                color: red;
                font-size: 24pt;
            }

            div.part {
                white-space: pre;
            }

            td {
                padding: 10px;
            }

            td.headers {
                width: 100px;
            }

            pre {
                width: 500px;
                overflow-x:scroll;
            }

            iframe {
                width: 400px;
                height: 400px;
            }
        </style>
    </head>
    <body>

    <h1>Fake Email Server</h1>

        {% if user_message %}
        <div id = 'user_message'>
            <span>{{ user_message }}</span>
        </div>
        {% endif %}

        {% block content %}
        {% endblock %}

        {% if address_name %}
        Access data api at <a href="/data/{{ address_name }}">/data/{{ address_name }}</a>
        {% endif %}
    </body>
</html>
